summaryrefslogtreecommitdiffstats
path: root/example/application.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-30 12:33:18 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-30 12:33:18 -0600
commit03bc485016127d419bbbbc3cfb09e21e8754b383 (patch)
treecad8234bcf26063239ac7a565298b897ffdeef57 /example/application.h
parent664e37abfe5c796c1279b8295fb030f126b0a7d8 (diff)
downloadtqscintilla-03bc485016127d419bbbbc3cfb09e21e8754b383.tar.gz
tqscintilla-03bc485016127d419bbbbc3cfb09e21e8754b383.zip
Initial automated TQt conversion
Diffstat (limited to 'example/application.h')
-rw-r--r--example/application.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/example/application.h b/example/application.h
index 6f48d41..a04ed15 100644
--- a/example/application.h
+++ b/example/application.h
@@ -3,7 +3,7 @@
**
** Copyright (C) 1992-2000 Trolltech AS. All rights reserved.
**
** This file is part of an example program for Qt. This example
** program may be used, distributed and modified without limitation.
**
*****************************************************************************/
@@ -11,37 +11,38 @@
#ifndef APPLICATION_H
#define APPLICATION_H
-#include <qmainwindow.h>
+#include <tqmainwindow.h>
class QextScintilla;
class QextScintillaPrinter;
-class ApplicationWindow: public QMainWindow
+class ApplicationWindow: public TQMainWindow
{
Q_OBJECT
+ TQ_OBJECT
public:
ApplicationWindow();
~ApplicationWindow();
protected:
- void closeEvent( QCloseEvent* );
+ void closeEvent( TQCloseEvent* );
private slots:
void newDoc();
void choose();
- void load( const QString &fileName );
+ void load( const TQString &fileName );
void save();
void saveAs();
void print();
void about();
- void aboutQt();
+ void aboutTQt();
private:
QextScintillaPrinter *printer;
QextScintilla *e;
- QString filename;
+ TQString filename;
};
@@ -3,7 +3,7 @@
** Copyright (C) 1992-2000 Trolltech AS. All rights reserved.
**
-** This file is part of an example program for Qt. This example
+** This file is part of an example program for TQt. This example
** program may be used, distributed and modified without limitation.
**